summaryrefslogtreecommitdiff
path: root/src/main.cpp
diff options
context:
space:
mode:
authorKraant <kraant@gmail.com>2008-08-07 21:36:18 +0000
committerKraant <kraant@gmail.com>2008-08-07 21:36:18 +0000
commitd63aff470f914d711b92af12ceb7944e8a6e24f4 (patch)
tree837585ea16854831dd6cd9ffc0592649076cc64a /src/main.cpp
parent128afe364bf797d02424b6e7191bb4bd4c1df21d (diff)
downloadMana-d63aff470f914d711b92af12ceb7944e8a6e24f4.tar.gz
Mana-d63aff470f914d711b92af12ceb7944e8a6e24f4.tar.bz2
Mana-d63aff470f914d711b92af12ceb7944e8a6e24f4.tar.xz
Mana-d63aff470f914d711b92af12ceb7944e8a6e24f4.zip
Rebranding TME to Aethyra
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/main.cpp b/src/main.cpp
index cc30ec0a..92e18906 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -198,18 +198,18 @@ void setUpdatesDir()
*/
void init_engine(const Options &options)
{
- homeDir = std::string(PHYSFS_getUserDir()) + "/.tme";
+ homeDir = std::string(PHYSFS_getUserDir()) + "/.aethyra";
#if defined WIN32
if (!CreateDirectory(homeDir.c_str(), 0) &&
GetLastError() != ERROR_ALREADY_EXISTS)
#elif defined __APPLE__
// Use Application Directory instead of .tme
homeDir = std::string(PHYSFS_getUserDir()) +
- "/Library/Application Support/The Mana Experiment";
+ "/Library/Application Support/Aethyra";
if ((mkdir(homeDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) != 0) &&
(errno != EEXIST))
#else
// Checking if /home/user/.tme folder exists.
if ((mkdir(homeDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) != 0) &&
(errno != EEXIST))
#endif
@@ -221,12 +221,12 @@ void init_engine(const Options &options)
}
// Set log file
- logger->setLogFile(homeDir + std::string("/tme.log"));
+ logger->setLogFile(homeDir + std::string("/aethyra.log"));
#ifdef PACKAGE_VERSION
- logger->log("Starting The Mana Experiment Version %s", PACKAGE_VERSION);
+ logger->log("Starting Aethyra Version %s", PACKAGE_VERSION);
#else
- logger->log("Starting The Mana Experiment - Version not defined");
+ logger->log("Starting Aethyra - Version not defined");
#endif
// Initialize SDL
@@ -268,7 +268,7 @@ void init_engine(const Options &options)
strncat(path, "/data", PATH_MAX - 1);
resman->addToSearchPath(path, true);
#else
- resman->addToSearchPath(TME_DATADIR "data", true);
+ resman->addToSearchPath(AETHYRA_DATADIR "data", true);
#endif
// Fill configuration with defaults
@@ -294,28 +294,28 @@ void init_engine(const Options &options)
// Checking if the configuration file exists... otherwise creates it with
// default options !
- FILE *tmeFile = 0;
+ FILE *aethyraFile = 0;
std::string configPath = options.configPath;
if (configPath.empty())
configPath = homeDir + "/config.xml";
- tmeFile = fopen(configPath.c_str(), "r");
+ aethyraFile = fopen(configPath.c_str(), "r");
// If we can't read it, it doesn't exist !
- if (tmeFile == NULL) {
+ if (aethyraFile == NULL) {
// We reopen the file in write mode and we create it
- tmeFile = fopen(configPath.c_str(), "wt");
+ aethyraFile = fopen(configPath.c_str(), "wt");
}
- if (tmeFile == NULL) {
+ if (aethyraFile == NULL) {
std::cout << "Can't create " << configPath << ". "
"Using Defaults." << std::endl;
} else {
- fclose(tmeFile);
+ fclose(aethyraFile);
config.init(configPath);
}
- SDL_WM_SetCaption("The Mana Experiment", NULL);
+ SDL_WM_SetCaption("Aethyra", NULL);
#ifdef WIN32
static SDL_SysWMinfo pInfo;
SDL_GetWMInfo(&pInfo);
@@ -325,7 +325,7 @@ void init_engine(const Options &options)
SetClassLong(pInfo.window, GCL_HICON, (LONG) icon);
}
#else
- SDL_Surface *icon = IMG_Load(TME_DATADIR "data/icons/tme.png");
+ SDL_Surface *icon = IMG_Load(AETHYRA_DATADIR "data/icons/aethyra.png");
if (icon)
{
SDL_SetAlpha(icon, SDL_SRCALPHA, SDL_ALPHA_OPAQUE);
@@ -422,7 +422,7 @@ void exit_engine()
void printHelp()
{
std::cout
- << "tme" << std::endl << std::endl
+ << "aethyra" << std::endl << std::endl
<< "Options: " << std::endl
<< " -h --help : Display this help" << std::endl
<< " -v --version : Display the version" << std::endl
@@ -439,10 +439,10 @@ void printHelp()
void printVersion()
{
#ifdef PACKAGE_VERSION
- std::cout << "The Mana Experiment version " << PACKAGE_VERSION <<
+ std::cout << "Aethyra version " << PACKAGE_VERSION <<
std::endl;
#else
- std::cout << "The Mana Experiment version " <<
+ std::cout << "Aethyra version " <<
"(local build?, PACKAGE_VERSION is not defined)" << std::endl;
#endif
}
@@ -198,18 +198,18 @@ void setUpdatesDir()
GetLastError() != ERROR_ALREADY_EXISTS)
#elif defined __APPLE__
- // Use Application Directory instead of .tme
+ // Use Application Directory instead of .aethyra
homeDir = std::string(PHYSFS_getUserDir()) +
@@ -198,18 +198,18 @@ void setUpdatesDir()
(errno != EEXIST))
#else
- // Checking if /home/user/.tme folder exists.
+ // Checking if /home/user/.Aethyra folder exists.
if ((mkdir(homeDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) != 0) &&
(errno != EEXIST))